package com.gic.enterprise.utils;

import java.util.List;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.log.LogUtils;
import com.gic.enterprise.exception.CommonException;
/**
 * controller统一返回结果
 * @ClassName: ResultControllerUtils 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/15 2:34 PM 
 */
public class ResultControllerUtils {

    public static final String LOG_NEW = "新增";
    public static final String LOG_EDIT = "修改";
    public static final String LOG_DELETE = "删除";
    public static final String LOG_SORT = "排序";

    /**
     * 新增/编辑/删除接口（含日志）
     * @param response
     * @return
     */
    public static RestResponse operationResult(ServiceResponse response, String content, String operationObject) {
        if (response.isSuccess()) {
            LogUtils.createLog(content, operationObject);
            return RestResponse.success(response.getResult());
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    public static String getOperationObject(ServiceResponse<String> result) {
        return result.isSuccess() ? result.getResult() : null;
    }

    /**
     * 统一返回成功结果
     * @Title: commonResult 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static RestResponse commonResult(ServiceResponse response) {
        if (response.isSuccess()) {
            return RestResponse.success(response.getResult());
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    /**
     * 返回正确结果
     * @Title: commonResultObject 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Object commonResultObject(ServiceResponse response) {
        if (response.isSuccess()) {
            return response.getResult();
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 返回分页正确结果
     * @Title: commonResultPage 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Page commonResultPage(ServiceResponse response) {
        if (response.isSuccess()) {
            return (Page) response.getResult();
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 返回分页正确结果
     * @Title: commonResultPage 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Page commonResultPage(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            Page page = (Page) response.getResult();
            page.setResult(EntityUtil.changeEntityListNew(clazz, page.getResult()));
            return page;
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 统一返回成功结果（分页DTO转为VO）
     * @Title: commonResultOfListVO 
     * @Description:
      * @author guojuxing
     * @param response
     * @param clazz 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    public static RestResponse commonPageResult(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            Page page = (Page) response.getResult();
            page.setResult(EntityUtil.changeEntityListNew(clazz, page.getResult()));
            return RestResponse.success(page);
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    /**
     * 统一返回成功结果 list（DTO转为VO）
     * @Title: commonResultOfListVO 
     * @Description:
      * @author guojuxing
     * @param response
     * @param clazz 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    public static RestResponse commonResult(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            return RestResponse.success(EntityUtil.changeEntityListNew(clazz, (List<?>) response.getResult()));
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    /**
     * 统一返回成功结果 单条数据（DTO转为VO）
     * @Title: commonResultOfListVO 
     * @Description:
      * @author guojuxing
     * @param response
     * @param clazz 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    public static RestResponse commonResultOne(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            return RestResponse.success(EntityUtil.changeEntityNew(clazz, response.getResult()));
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }
}
